structure

package
v0.0.4-rc.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 12, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package structure defines the public structural semantics layer for MALT.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Proof

type Proof []byte

Proof is an opaque proof payload returned by a structural semantic. Concrete implementations define the exact encoding.

Directories

Path Synopsis
Package list defines the public stable-indexed list semantic for MALT.
Package list defines the public stable-indexed list semantic for MALT.
Package mapping defines the public keyed-map semantic for MALT.
Package mapping defines the public keyed-map semantic for MALT.

Jump to