Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Resolver ¶
type Resolver interface {
ResolveKey(root cid.Cid, path string) (*resolver.ResolveResult, error)
Resolve(root cid.Cid, path string) (*resolver.ResolveResult, error)
VerifyTranscript(root cid.Cid, transcript *resolver.Transcript) (bool, error)
}
Resolver is the graph read/proof port.
type Writer ¶
type Writer interface {
Apply(ctx context.Context, namespace string, mut writer.SemanticMutation) (writer.WriteReceipt, error)
CreateStructure(ctx context.Context, namespace string, arcs arcset.ArcSet) (cid.Cid, error)
UpdateArc(ctx context.Context, namespace string, root cid.Cid, path string, newTarget cid.Cid) (*writer.UpdateResult, error)
BatchUpdateArcs(ctx context.Context, namespace string, root cid.Cid, updates map[string]cid.Cid) (*writer.BatchUpdateResult, error)
GetArc(ctx context.Context, namespace string, root cid.Cid, path string) (cid.Cid, error)
GetSnapshot(ctx context.Context, namespace string, root cid.Cid) (arcset.ArcSet, error)
}
Writer is the graph mutation port.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package querypath implements locked path canonicalization for stat and content APIs.
|
Package querypath implements locked path canonicalization for stat and content APIs. |
|
Package resolver implements the MALT explicit-arc resolution loop with prefix consumption.
|
Package resolver implements the MALT explicit-arc resolution loop with prefix consumption. |
|
step
Package step defines the Step interface for single-step resolution.
|
Package step defines the Step interface for single-step resolution. |
|
step/explicit
Package explicit implements the Step interface for MALT explicit arcs.
|
Package explicit implements the Step interface for MALT explicit arcs. |
|
Package writer implements graph semantic mutations.
|
Package writer implements graph semantic mutations. |
Click to show internal directories.
Click to hide internal directories.